@@ -129,9 +129,10 @@ decoded (FishSound * fsound, float ** pcm, long frames, void * user_data)
 }
 
 static int
-read_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_packet (OGGZ * oggz, oggz_packet * ozp, long serialno, void * user_data)
 {
   FS_DecEnc * ed = (FS_DecEnc *) user_data;
+  ogg_packet *op = &ozp->op;
   
   fish_sound_prepare_truncation (ed->decoder, op->granulepos, op->e_o_s);
   fish_sound_decode (ed->decoder, op->packet, op->bytes);
