@@ -60,9 +60,9 @@ dump_identity (unsigned char * buf, long bytes)
 }
 
 static int
-read_packet (OGGZ * oggz, ogg_packet * op, long serialno, void * user_data)
+read_packet (OGGZ * oggz, oggz_packet * ozp, long serialno, void * user_data)
 {
-
+  ogg_packet *op = &ozp->op;
   if (op->bytes < 8) {
     printf ("too short\n");
   } else {
