@@ -56,7 +56,14 @@
 
 #define BITS_PER_SAMPLE 24
 
-typedef struct _FishSoundFlacInfo {
+#if defined(HAVE_FLAC_1_1_3)
+#  define flac_callback_bytes_type size_t
+#else
+#  define flac_callback_bytes_type unsigned int
+#endif
+
+
+typedef struct {
   FLAC__StreamDecoder *fsd;
   FLAC__StreamEncoder *fse;
   unsigned char * buffer;
@@ -106,7 +113,7 @@ fs_flac_command (FishSound * fsound, int command, void * data, int datasize)
 #if FS_DECODE
 static FLAC__StreamDecoderReadStatus
 fs_flac_read_callback(const FLAC__StreamDecoder *decoder,
-                      FLAC__byte buffer[], unsigned int *bytes,
+                      FLAC__byte buffer[], flac_callback_bytes_type *bytes,
                       void *client_data)
 {
   FishSound* fsound = (FishSound*)client_data;
@@ -121,7 +128,7 @@ fs_flac_read_callback(const FLAC__StreamDecoder *decoder,
   }
 
   memcpy(buffer, fi->buffer, fi->bufferlength);
-  *bytes = (unsigned int)fi->bufferlength;
+  *bytes = (flac_callback_bytes_type)fi->bufferlength;
   fi->bufferlength = 0;
   return FLAC__STREAM_DECODER_READ_STATUS_CONTINUE;
 }
@@ -259,7 +266,7 @@ fs_flac_decode_header (FishSound * fsound, unsigned char *buf, long bytes)
        fs_flac_meta_callback,
        fs_flac_error_callback,
        fsound
-       ) != FLAC__STREAM_DECODER_SEARCH_FOR_METADATA)
+       ) != FLAC__STREAM_DECODER_INIT_STATUS_OK)
      return NULL;
 #endif
 
@@ -346,7 +353,7 @@ dec_err:
 #if FS_ENCODE
 static FLAC__StreamEncoderWriteStatus
 fs_flac_enc_write_callback(const FLAC__StreamEncoder *encoder,
-                           const FLAC__byte buffer[], unsigned bytes,
+                           const FLAC__byte buffer[], flac_callback_bytes_type bytes,
                            unsigned samples, unsigned current_frame,
                            void *client_data)
 {
@@ -354,7 +361,7 @@ fs_flac_enc_write_callback(const FLAC__StreamEncoder *encoder,
   FishSoundFlacInfo *fi = fsound->codec_data;
 
   debug_printf(1, "IN");
-  debug_printf(1, "bytes: %d, samples: %d", bytes, samples);
+  debug_printf(1, "bytes: %lld, samples: %d", (long long) bytes, samples);
 
   if (fsound->callback.encoded) {
     FishSoundEncoded encoded = (FishSoundEncoded) fsound->callback.encoded;
@@ -541,6 +548,7 @@ fs_flac_encode_vorbiscomments (FishSound * fsound)
   metadata->is_last = true;
   metadata->length = total_length;
   /* Don't bother setting the vendor_string, as libFLAC ignores it */
+  metadata->data.vorbis_comment.vendor_string.length = 0;
   metadata->data.vorbis_comment.num_comments = length;
   metadata->data.vorbis_comment.comments = comments;
 
@@ -599,7 +607,7 @@ fs_flac_enc_headers (FishSound * fsound)
        NULL, /* tell callback */
        fs_flac_enc_meta_callback,
        fsound
-       ) != FLAC__STREAM_ENCODER_OK)
+       ) != FLAC__STREAM_ENCODER_INIT_STATUS_OK)
      return NULL;
 
 #endif
@@ -728,10 +736,13 @@ fs_flac_delete (FishSound * fsound)
   }
 
   if (fi->ipcm) fs_free(fi->ipcm);
+
+#if FS_DECODE
   for (i = 0; i < 8; i++) {
     if (fi->pcm_out[i]) fs_free (fi->pcm_out[i]);
   }
-  
+#endif /* FS_DECODE */
+
 #if FS_ENCODE
   if (fi->enc_vc_metadata) {
     fs_flac_metadata_free (fi->enc_vc_metadata);
@@ -795,9 +806,12 @@ fs_flac_init (FishSound * fsound)
   fi->header_packets = 0;
 
   fi->ipcm = NULL;
+
+#if FS_DECODE
   for (i = 0; i < 8; i++) {
     fi->pcm_out[i] = NULL;
   }
+#endif /* FS_DECODE */
 
 #if FS_ENCODE
   fi->enc_vc_metadata = NULL;
