@@ -58,6 +58,9 @@ decoded (FishSound * fsound, float ** pcm, long frames, void * user_data)
 {
   const FishSoundComment * comment;
 
+  if (fsound == NULL)
+    FAIL ("No Fish Found");
+
   INFO ("+ Retrieving first (expect ARTIST1)");
   comment = fish_sound_comment_first (fsound);
 
@@ -213,6 +216,9 @@ fs_encdec_comments_test (int format, int blocksize)
 
   fish_sound_encode (ed->encoder, ed->pcm, blocksize);
 
+  fish_sound_flush (ed->encoder);
+  fish_sound_flush (ed->decoder);
+
   fs_encdec_delete (ed);
 
   return 0;
@@ -231,5 +237,10 @@ main (int argc, char * argv[])
   fs_encdec_comments_test (FISH_SOUND_SPEEX, 2048);
 #endif
 
+#if HAVE_FLAC
+  INFO ("Testing encode/decode pipeline for comments: FLAC");
+  fs_encdec_comments_test (FISH_SOUND_FLAC, 2048);
+#endif
+
   exit (0);
 }
